# moderation — features


本 domain 下的所有功能：

- ✅ [FEAT-022 block](./FEAT-022-block.md) — done
- ✅ [FEAT-023 unblock](./FEAT-023-unblock.md) — done
- ✅ [FEAT-024 blocklist](./FEAT-024-blocklist.md) — done
- 📋 [FEAT-025 user-ban](./FEAT-025-user-ban.md) — planned
